boofun.core.gpu\_acceleration
=============================

.. automodule:: boofun.core.gpu_acceleration


   .. rubric:: Functions

   .. autosummary::

      benchmark_gpu_performance
      get_gpu_info
      gpu_accelerate
      is_gpu_available
      set_gpu_backend
      should_use_gpu

   .. rubric:: Classes

   .. autosummary::

      CuPyAccelerator
      GPUAccelerator
      GPUDevice
      GPUManager
      NumbaAccelerator
